@@ -36,6 +36,7 @@ InboxModel::InboxModel (QObject * parent)
     roles[IN_Link]      = "link";
     roles[IN_TimeDetail]= "time_detail";
     roles[IN_SmsText]   = "smstext";
+    roles[IN_ReadFlag]  = "is_read";
     setRoleNames(roles);
 }//InboxModel::InboxModel
 
@@ -77,6 +78,9 @@ InboxModel::data (const QModelIndex &index,
         case IN_NumberRole:
             column = 4;
             break;
+        case IN_ReadFlag:
+            column = 5;
+            break;
         case IN_SmsText:
             column = 6;
             break;
@@ -190,6 +194,14 @@ InboxModel::data (const QModelIndex &index,
             GVAccess::beautify_number (strNum);
             var = strNum;
         }
+        else if (5 == column)   // GV_IN_FLAGS
+        {
+            if (IN_ReadFlag == role) {
+                var = QVariant(bool(var.toInt() & (1 << 0) ? true : false));
+            } else {
+                var.clear ();
+            }
+        }
         else if (6 == column)   // GV_IN_SMSTEXT
         {
             // Just return the data as is.
@@ -317,3 +329,29 @@ InboxModel::insertEntry (const GVInboxEntry &hEvent)
 
     return (true);
 }//InboxModel::insertEntry
+
+bool
+InboxModel::markAsRead (const QString &msgId)
+{
+    CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
+    if (!dbMain.markAsRead (msgId)) {
+        qWarning ("Failed to mark read.");
+        return (false);
+    }
+
+/*@@Uv : This works for a single change, but for whatever reason does not get
+         the data through the underlying SQL query. Cached data - that still has
+         the unread flag - is returned.
+
+    QVariant val = msgId;
+    QModelIndexList indexList = match(index(0,0), Qt::EditRole, val);
+
+    foreach (QModelIndex mi, indexList) {
+        emit dataChanged (mi.sibling(mi.row (), 5), mi.sibling(mi.row (), 5));
+    }
+*/
+
+    dbMain.refreshInboxModel (this, strSelectType);
+
+    return (true);
+}//InboxModel::markAsRead
