@@ -42,6 +42,13 @@ public slots:
 protected:
     QString userAgentForUrl (const QUrl & url) const;
 
+    inline bool acceptNavigationRequest (QWebFrame * /*frame*/,
+                                         const QNetworkRequest & /*request*/,
+                                         QWebPage::NavigationType /*type*/)
+    { return true; }
+
+    QWebPage *createWindow (QWebPage::WebWindowType type);
+
 protected:
     bool bUAIsIphone;
 };
